Installation
============

Stable Version
--------------

Install the latest stable release from PyPI:

.. code-block:: bash

   pip install nadzoring

Development Version
-------------------

To install the latest development version directly from GitHub:

.. code-block:: bash

   pip install git+https://github.com/alexeev-prog/nadzoring.git

Requirements
------------

* Python 3.12 or higher
* Works on Linux, Windows, and macOS
